import { type Express } from "express";
import { createServer, type Server } from "http";
import { storage } from "./storage";
import { contactSchema } from "@shared/schema";
import { ZodError } from "zod";
import path from "path";
import express from "express";

export async function registerRoutes(app: Express): Promise<Server> {
  // Serve static files from the public directory
  app.use('/public', express.static(path.join(process.cwd(), 'public')));
  
  // Serve the download page
  app.get('/download', (req, res) => {
    res.sendFile(path.join(process.cwd(), 'public', 'download.html'));
  });
  
  // Serve the portable project download page
  app.get('/portable-project', (req, res) => {
    res.send(`
      <!DOCTYPE html>
      <html lang="en">
      <head>
          <meta charset="UTF-8">
          <meta name="viewport" content="width=device-width, initial-scale=1.0">
          <title>Burlatech - Download Portable Project</title>
          <style>
              body {
                  font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
                  line-height: 1.6;
                  color: #333;
                  background-color: #f8f9fa;
                  margin: 0;
                  padding: 0;
              }
              .container {
                  max-width: 800px;
                  margin: 0 auto;
                  padding: 40px 20px;
              }
              h1 {
                  color: #2d3748;
                  margin-bottom: 25px;
                  font-size: 2.2rem;
              }
              p {
                  margin-bottom: 20px;
                  font-size: 1.1rem;
              }
              .download-button {
                  display: inline-block;
                  background-color: #4CAF50;
                  color: white;
                  padding: 12px 24px;
                  text-decoration: none;
                  border-radius: 4px;
                  font-size: 1.1rem;
                  font-weight: 600;
                  transition: background-color 0.3s;
              }
              .download-button:hover {
                  background-color: #45a049;
              }
              .instructions {
                  margin-top: 40px;
                  padding: 25px;
                  background-color: #ffffff;
                  border-radius: 8px;
                  box-shadow: 0 2px 10px rgba(0,0,0,0.1);
              }
              h2 {
                  color: #2d3748;
                  margin-top: 0;
              }
              ol, ul {
                  padding-left: 20px;
              }
              li {
                  margin-bottom: 10px;
              }
              strong {
                  font-weight: 600;
              }
              code {
                  background-color: #f1f1f1;
                  padding: 3px 6px;
                  border-radius: 3px;
                  font-family: Consolas, Monaco, 'Andale Mono', monospace;
                  font-size: 0.9rem;
              }
          </style>
      </head>
      <body>
          <div class="container">
              <h1>Burlatech Portable Project</h1>
              
              <p>This page allows you to download the complete Burlatech website project files for deploying anywhere.</p>
              
              <a href="/public/burlatech-portable-project.zip" class="download-button" download>Download Portable Project (.zip)</a>
              
              <div class="instructions">
                  <h2>Setup Instructions</h2>
                  <p>Follow these steps to set up and deploy the Burlatech website on your own server:</p>
                  
                  <ol>
                      <li>Download the .zip file using the button above</li>
                      <li>Extract the contents to your project directory</li>
                      <li>Install dependencies:
                          <pre><code>npm install</code></pre>
                      </li>
                      <li>For development, start the server:
                          <pre><code>npm run dev</code></pre>
                      </li>
                      <li>For production build:
                          <pre><code>npm run build</code></pre>
                      </li>
                      <li>Deploy the contents of the <code>dist</code> folder to your web server</li>
                  </ol>
                  
                  <h2>Project Structure</h2>
                  <ul>
                      <li><code>client/</code> - Frontend React application</li>
                      <li><code>server/</code> - Backend Express server</li>
                      <li><code>shared/</code> - Shared code between client and server</li>
                      <li><code>attached_assets/</code> - Images and other assets</li>
                  </ul>
                  
                  <h2>Requirements</h2>
                  <ul>
                      <li>Node.js v18+ (v20 recommended)</li>
                      <li>npm v9+ (comes with Node.js)</li>
                  </ul>
                  
                  <p>All Replit-specific code and dependencies have been removed for easy deployment anywhere.</p>
              </div>
          </div>
      </body>
      </html>
    `);
  });

  // Serve the production build download page
  app.get('/production-download', (req, res) => {
    res.send(`
      <!DOCTYPE html>
      <html lang="en">
      <head>
          <meta charset="UTF-8">
          <meta name="viewport" content="width=device-width, initial-scale=1.0">
          <title>Burlatech - Download Production Build</title>
          <style>
              body {
                  font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
                  line-height: 1.6;
                  color: #333;
                  background-color: #f8f9fa;
                  margin: 0;
                  padding: 0;
              }
              .container {
                  max-width: 800px;
                  margin: 0 auto;
                  padding: 40px 20px;
              }
              h1 {
                  color: #2d3748;
                  margin-bottom: 25px;
                  font-size: 2.2rem;
              }
              p {
                  margin-bottom: 20px;
                  font-size: 1.1rem;
              }
              .download-button {
                  display: inline-block;
                  background-color: #4CAF50;
                  color: white;
                  padding: 12px 24px;
                  text-decoration: none;
                  border-radius: 4px;
                  font-size: 1.1rem;
                  font-weight: 600;
                  transition: background-color 0.3s;
              }
              .download-button:hover {
                  background-color: #45a049;
              }
              .instructions {
                  margin-top: 40px;
                  padding: 25px;
                  background-color: #ffffff;
                  border-radius: 8px;
                  box-shadow: 0 2px 10px rgba(0,0,0,0.1);
              }
              h2 {
                  color: #2d3748;
                  margin-top: 0;
              }
              ol, ul {
                  padding-left: 20px;
              }
              li {
                  margin-bottom: 10px;
              }
              strong {
                  font-weight: 600;
              }
          </style>
      </head>
      <body>
          <div class="container">
              <h1>Burlatech Production Build</h1>
              
              <p>This page allows you to download the production-ready build of the Burlatech website.</p>
              
              <a href="/public/burlatech-production-build.zip" class="download-button" download>Download Production Build (.zip)</a>
              
              <div class="instructions">
                  <h2>Deployment Instructions</h2>
                  <p>Follow these steps to deploy the website to your hosting provider:</p>
                  
                  <ol>
                      <li>Download the .zip file using the button above</li>
                      <li>Extract the contents using any archive tool (like 7-Zip, WinRAR, or unzip command on Mac/Linux)</li>
                      <li>Upload the extracted files to your hosting provider:
                          <ul>
                              <li><strong>Namecheap</strong>: Upload via FTP or cPanel File Manager to your hosting account</li>
                              <li><strong>DigitalOcean</strong>: Upload to your App Platform or Droplet</li>
                              <li><strong>AWS</strong>: Upload to S3 bucket with static website hosting enabled</li>
                              <li><strong>Standard Web Hosting</strong>: Upload to the public_html or www directory</li>
                          </ul>
                      </li>
                      <li>No build step is required - the files are ready to serve</li>
                  </ol>
                  
                  <p>The production build includes all HTML, CSS, JavaScript, and assets needed to run the Burlatech website. These are the exact files that would be produced by running 'npm run build' in a standard React project.</p>
              </div>
          </div>
      </body>
      </html>
    `);
  });
  
  // Contact form submission endpoint
  app.post("/api/contact", async (req, res) => {
    try {
      // Validate request body against schema
      const contactData = contactSchema.parse(req.body);
      
      // Store contact submission
      const contact = await storage.createContact(contactData);
      
      // Return success response
      return res.status(201).json({
        message: "Contact form submitted successfully",
        contact
      });
    } catch (error) {
      // Handle validation errors
      if (error instanceof ZodError) {
        return res.status(400).json({
          message: "Invalid form data",
          errors: error.errors
        });
      }
      
      // Handle other errors
      console.error("Error saving contact form:", error);
      return res.status(500).json({
        message: "An error occurred while processing your request"
      });
    }
  });

  const httpServer = createServer(app);
  return httpServer;
}
